
Example of 'mathjax' usage
==========================

see `mathjax extension page`_ for more documentation.

`:math:`a^2 + b^2 = c^2`` will produce :math:`a^2 + b^2 = c^2`.

Block version:

.. math::

   (a + b)^2 = a^2 + 2ab + b^2

   (a - b)^2 = a^2 - 2ab + b^2

.. _`mathjax extension page`: http://www.sphinx-doc.org/en/stable/ext/math.html
